==> haskell-oeis-0.3.10.1-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-oeis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 oeis
version:              0.3.10.1
visibility:           public
id:                   oeis-0.3.10.1-EJCMTDT3gHj7iSmZnoZLTg
key:                  oeis-0.3.10.1-EJCMTDT3gHj7iSmZnoZLTg
license:              BSD-3-Clause
maintainer:           Bartosz Nitka <niteria@gmail.com>
author:               Brent Yorgey
stability:            experimental
synopsis:
    Interface to the Online Encyclopedia of Integer Sequences (OEIS)

description:
    Interface to the <http://oeis.org/ Online Encyclopedia of Integer Sequences (OEIS)>.

category:             Math
abi:                  b19169684093ea728482b44c2e77e7c2
exposed:              True
exposed-modules:      Math.OEIS Math.OEIS.Internal
hidden-modules:       Math.OEIS.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-oeis
hs-libraries:         HSoeis-0.3.10.1-EJCMTDT3gHj7iSmZnoZLTg
depends:
    base-4.17.2.1 http-client-0.7.19-veq4MTHniy21v9pOYpRdd
    http-client-tls-0.3.6.4-BtAmNja0oKIEdL14Ub64ie
    http-types-0.12.4-KxfEKIoLDdBKlrGUyHct4y
    network-3.1.4.0-HbZCj3UHcZsFvn6ftFrD4m
    network-uri-2.6.4.2-BuPsn3YVnowHuszetfOccY
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-oeis/html/oeis.haddock
haddock-html:         /usr/share/doc/haskell-oeis/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-oeis-0.3.10.1-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-oeis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 oeis
version:              0.3.10.1
visibility:           public
id:                   oeis-0.3.10.1-8I7yifm4YzwAxt1hYFafKp
key:                  oeis-0.3.10.1-8I7yifm4YzwAxt1hYFafKp
license:              BSD-3-Clause
maintainer:           Bartosz Nitka <niteria@gmail.com>
author:               Brent Yorgey
stability:            experimental
synopsis:
    Interface to the Online Encyclopedia of Integer Sequences (OEIS)

description:
    Interface to the <http://oeis.org/ Online Encyclopedia of Integer Sequences (OEIS)>.

category:             Math
abi:                  4fbe16c520634b3bc7056b7285c4400d
exposed:              True
exposed-modules:      Math.OEIS Math.OEIS.Internal
hidden-modules:       Math.OEIS.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-oeis
hs-libraries:         HSoeis-0.3.10.1-8I7yifm4YzwAxt1hYFafKp
depends:
    base-4.17.2.1 http-client-0.7.19-INRexYbbc84G8M9afYhYa4
    http-client-tls-0.3.6.4-4b1LqwZqELbD3PiYpWlMw1
    http-types-0.12.4-BDAI9vbdFnhAzARYRhzpQY
    network-3.1.4.0-480JOeNLV9o5fbqpzcHJCB
    network-uri-2.6.4.2-DCTjueINivX2RvibFUmCb5
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-oeis/html/oeis.haddock
haddock-html:         /usr/share/doc/haskell-oeis/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
